==> hermes-2.5.1.22.tar.gz: hermes-2.5.1.22/lib/hermes/bo_client/tasks/cancel_status_task.rb <==
# frozen_string_literal: true


=begin
nud = Hermes::Nud.first
ha = Hermes::HousingApplication.first
   code = "RADATT"
  
      so = Hermes::BoClient::CancelStatusTask.new({
                                               housing_request_id: ha.housing_request_id,
                                               housing_offer_id: ha.housing_offer_id
                                              })
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end

module Hermes
  module BoClient
    class CancelStatusTask < BaseTask
      
      def initialize(options = {})
        @xsd = 'AnnulationCandidature.xsd'
        super(options)
      end
      
      endpoint {'/ws/rest/als/demande/v1/annulerCandidature'}
      
      task_name 'cancelstatus'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingApplicationMap'
      
      params *%i[
        refInterneDemande
        refInterneOffre
        dateAnnulation
      ]
      
      def to_xml
        namespaces = {
            'xmlns:ns2' => 'http://v1.als.ikos.webservice.immobilier.sopra/demande/annulerCandidature'
        }
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
          b[:ns2].propositionEvenement(namespaces) do
            
            b.refInterneDemande mapping.refInterneDemande do
              b.parent.namespace = nil
            end
            b.refInterneOffre mapping.refInterneOffre do
              b.parent.namespace = nil
            end
		        b.dateAnnulation mapping.status_updated_at do
              b.parent.namespace = nil
            end
          end
         
        end
        builder.to_xml
      end
    end
  end
end

==> hermes-5.3.0.18.tar.gz: hermes-5.3.0.18/lib/hermes/bo_client/tasks/cancel_status_task.rb <==
# frozen_string_literal: true


=begin
nud = Hermes::Nud.first
ha = Hermes::HousingApplication.first
   code = "RADATT"
  
      so = Hermes::BoClient::CancelStatusTask.new({
                                               housing_request_id: ha.housing_request_id,
                                               housing_offer_id: ha.housing_offer_id
                                              })
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end

module Hermes
  module BoClient
    class CancelStatusTask < BaseTask
      
      def initialize(options = {})
        @xsd = 'AnnulationCandidature.xsd'
        super(options)
      end
      
      endpoint {'/ws/rest/als/demande/v1/annulerCandidature'}
      
      task_name 'cancelstatus'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingApplicationMap'
      
      params *%i[
        refInterneDemande
        refInterneOffre
        dateAnnulation
      ]
      
      def to_xml
        namespaces = {
            'xmlns:ns2' => 'http://v1.als.ikos.webservice.immobilier.sopra/demande/annulerCandidature'
        }
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
          b[:ns2].annulerCandidature(namespaces) do
            
            b.refInterneDemande mapping.refInterneDemande do
              b.parent.namespace = nil
            end
            b.refInterneOffre mapping.refInterneOffre do
              b.parent.namespace = nil
            end
		        b.dateAnnulation mapping.status_updated_at do
              b.parent.namespace = nil
            end
          end
         
        end
        builder.to_xml
      end
    end
  end
end
